<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi_FI" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Versio %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 on vapaa ohjelmisto, mutta sen kehitys vie arvokasta aikaa.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Lahjoita&lt;/a&gt; tukeaksesi %2n jatkokehitystä.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Julkaistu &lt;a href=&apos;%1&apos;&gt;GNU-hankkeen yleisellä lisenssillä&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Mitä olet aina halunnut tietää sovelluksesta %1, mutta et ole koskaan kysynyt</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Saatat haluta koettaa myös muita sovelluksiani:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, YouTube-sovellus</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, YouTube-musiikkisoitin</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Käännä %1 omalle kielellesi %2-palvelussa</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Lisensoitu henkilölle: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Syötä tähän lisenssitietosi</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Sähköposti:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Koodi:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Lisensioi %1.</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Tämä demon kokeiluaika on päättynyt.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Ilman lisenssiä tämä sovellus vanhenee %1 päivässä.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ostamalla täyden version tuet työtäni %1n parissa.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Käytä demoa</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Syötä lisenssi</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Osta lisenssi</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>Täysversio sallii sinun lisätä useamman kuin %1 kappaletta soittolistaan ja kuunnella musiikkia keskeytyksettä.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Osta palvelusta %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Lue lisää</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Artisti</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Vuosi</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Suosio</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Käänteinen järjestys</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Järjestysperuste</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Lue lisää</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Kappalemäärä</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Levymäärä</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Vuosi</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Suosio</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Käänteinen järjestys</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Järjestysperuste</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Takaisin</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Siirry takaisin</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Tervetuloa, käytössäsi on &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 haluaa tutkia musiikkikokoelmasi.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Käytä iTunes-kokoelmaa</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Käytä %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Valitse kansio...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 yhdistää Last.fm-verkkopalveluihin ja välittää esittäjän sekä levyn nimen noutaakseen kansitaiteen, biografian ja paljon muuta.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Jos sinua mietityttää tämän yksityisyys, voit lopettaa nyt.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Missä musiikkikokoelmasi on?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Valitse musiikkikokoelmasi sijainti.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Paikallista kokoelmasi</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Tutkinta on jo käynnissä</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 tutkii musiikkikirjastoasi.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 käyttää palvelua &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; musiikkisi luettelointiin.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Tämä vie jonkun hetken riiippuen kirjastosi koosta ja verkkoyhteytesi nopeudesta.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Käy hakemassa kahvia</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Ladataan päivitystä...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Pudota tähän lisätäksesi soittolistaan</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Esittäjät</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Levyt</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Kansiot</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Soita</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Soita/keskeytä</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Pysäytä soitto nykyisen kappaleen jälkeen</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Seuraava kappale</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Edellinen kappale</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Nosta äänenvoimakkuutta</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Laske äänenvoimakkuutta</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Vaimenna</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Hae eteenpäin</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Hae taaksepäin</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Tunnistautuminen epäonnistui</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Kirjaudu palveluun %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Käyttäjätunnus:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Salasana:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Rekisteröi %1-tunnus</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Unohditko &lt;a href=&apos;%1&apos;&gt;käyttäjätunnuksesi&lt;/a&gt; tai &lt;a href=&apos;%2&apos;&gt;salasanasi&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Takaisin</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Mene edelliseen näkymään</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>Tie&amp;dot</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Näytä tietoja nykyisestä kappaleesta</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>E&amp;dellinen</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Siirry edelliseen kappaleeseen</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Seuraava</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Siirry seuraavaan kappaleeseen</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Soita</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Aloita soitto</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Koko näyttö</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Siirry koko näytön tilaan</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Poista valitut kappaleet soittolistasta</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Siirrä &amp;ylös</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Siirrä valitut kappaleet ylemmäs soittolistalla</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Siirrä &amp;alas</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Siirrä valitut kappaleet alemmas soittolistalla</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Lopeta</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Näkemiin</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Muuta kokoelmakansiota...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Valitse toinen kokoelmakansio</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Verkkosivu</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 internetissä</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>La&amp;hjoita</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>%1 arvostaa kehitykseen antamaasi tukea</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Tietoja - %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>T&amp;yhjennä</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Poista kaikki kappaleet soittolistalta</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Sekoita</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Satunnainen soittolistatila</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Toista</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Toista ensimmäinen kappale uudestaan, kun kaikki laulut on toistettu</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Vaimenna äänet</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Sovellus</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Toisto</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>So&amp;ittolista</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Näkymä</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Paina %1 nostaaksesi äänenvoimakkuutta, %2 laskeaksesi äänenvoimakkuutta</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Avataan %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Päivitetään kokoelmaa...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Päivitetään kokoelmaa - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Kokoelma päivitetty</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Kohtalokas virhe: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Virhe: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>&amp;Poistu koko näytön tilasta</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Aikaa jäljellä: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Äänenvoimakkuus %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Äänet on vaimennettu</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ääni on palautettu</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Hanki täysversio</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versio %2 on nyt saatavilla.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Muistuta myöhemmin</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ikkuna</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Pienennä</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Osta %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>Py&amp;säytä tämän kappaleen jälkeen</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Scrobblaus</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Lähetä soitetut kappalenimet palveluun %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Kirjaudu ulos palvelusta %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Ilmoita ongelmasta...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 sai valmiiksi musiikkikokoelmasi tutkimisen</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Pidätkö %1sta? Arvostele se!</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Pudota kohteet tähän</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Soittolista soitettiin loppuun</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Tämä on sovelluksen %1 demoversio.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Se sallii muutamien kappaleiden toistamisen, jotta voit testata sovellusta ja todeta sen toimivuuden itselläsi.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Hanki täysversio</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Uusi versio sovelluksesta %1 on saatavilla!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 on nyt saatavilla. Sinulla on %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Haluatko ladata sen nyt?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Ohita tämä versio</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Muistuta minua myöhemmin</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Asenna päivitys</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Liitä</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Tässä demossa soittolistan koko on rajoitettu %1 kappaleeseen.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Soittolista on tyhjä</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 kappaletta - kokonaiskesto %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Hakusi ei tuottanut tuloksia.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Kappaleet</translation>
    </message>
</context>
</TS>